# Snapshot report for `test/js/topicDataTest.js`

The actual snapshot is saved in `topicDataTest.js.snap`.

Generated by [AVA](https://ava.li).

## basic structure

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        topic: 'awesomeTopic2',
        vector3: Vector3 {
          x: 2000.1,
          y: 100,
          z: 567.000678,
        },
      },
    }

## boolean

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        boolean: false,
        topic: 'awesomeTopic',
      },
    }

## color

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        color: Color {
          a: 0.5,
          b: 0.5,
          g: 0.5,
          r: 1,
        },
        topic: 'awesomeTopic',
      },
    }

## matrix3x2

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        matrix3x2: Matrix3x2 {
          m00: 723974298.89,
          m01: 8275786.809088,
          m10: 1324.89,
          m11: 5473.809088,
          m20: 36735.89,
          m21: 3736753.36573,
        },
        topic: 'awesomeTopic',
      },
    }

## matrix4x4

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        matrix4x4: Matrix4x4 {
          m00: 723974298.89,
          m01: 8275786.809088,
          m02: 723974298.89,
          m03: 8275786.809088,
          m10: 56765.5673,
          m11: 98679.689689,
          m12: 689667.89,
          m13: 46746.809047588,
          m20: 4675.89,
          m21: 82755674786.80962,
          m22: 7235467974298.846,
          m23: 82754567786.80946,
          m30: 46746577645.89,
          m31: 82754657786.80948,
          m32: 4567.89,
          m33: 47467.809047688,
        },
        topic: 'awesomeTopic',
      },
    }

## number

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        number: 8098,
        topic: 'awesomeTopic',
      },
    }

## quaternion

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        quaternion: Quaternion {
          w: 76897908098.9808,
          x: 723974298.89,
          y: 8275786.809088,
          z: 798789.0000008,
        },
        topic: 'awesomeTopic',
      },
    }

## string

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        string: 'I am a string',
        topic: 'awesomeTopic',
      },
    }

## vector2

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        topic: 'awesomeTopic',
        vector2: Vector2 {
          x: 723974298.89,
          y: 8275786.809088,
        },
      },
    }

## vector3

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        topic: 'awesomeTopic',
        vector3: Vector3 {
          x: 723974298.89,
          y: 8275786.809088,
          z: 798789.0000008,
        },
      },
    }

## vector4

> Snapshot 1

    TopicData {
      deviceIdentifier: 'superDevice',
      topicDataRecord: TopicDataRecord {
        topic: 'awesomeTopic',
        vector4: Vector4 {
          w: 76897908098.9808,
          x: 723974298.89,
          y: 8275786.809088,
          z: 798789.0000008,
        },
      },
    }
